import request from '@/utils/request'

// 创建体检信息
export function createxyMain(data) {
  return request({
    url: '/system/xy-main/create',
    method: 'post',
    data: data
  })
}

// 更新体检信息
export function updatexyMain(data) {
  return request({
    url: '/system/xy-main/update',
    method: 'put',
    data: data
  })
}

// 删除体检信息
export function deletexyMain(id) {
  return request({
    url: '/system/xy-main/delete?id=' + id,
    method: 'delete'
  })
}

// 获得体检信息
export function getxyMain(id) {
  return request({
    url: '/system/xy-main/get?id=' + id,
    method: 'get'
  })
}

// 获得体检信息分页
export function getxyMainPage(query) {
  return request({
    url: '/system/xy-main/page',
    method: 'get',
    params: query
  })
}

// 导出体检信息 Excel
export function exportxyMainExcel(query) {
  return request({
    url: '/system/xy-main/export-excel',
    method: 'get',
    params: query,
    responseType: 'blob'
  })
}
